import { Component, OnInit } from '@angular/core'
import { ActivatedRoute } from '@angular/router'
import { Location } from '@angular/common'

import { Mieter } from '../mieter'
import { ZahlungForderung } from '../zahlung-forderung'
import { MieterService} from '../mieter.service'
import { ZahlungForderungService} from '../zahlung-forderung.service'
import { MessageService } from '../message.service'

@Component({
  selector: 'app-mieter-detail',
  templateUrl: './mieter-detail.component.html',
  styleUrls: ['./mieter-detail.component.css']
})
export class MieterDetailComponent implements OnInit {

  mieter: Mieter
  year: string
  zahlungenForderungen : ZahlungForderung[]


  constructor(
    private mieterService: MieterService, 
    private zahlungForderungService: ZahlungForderungService,
    private messageService: MessageService,
    private route: ActivatedRoute,
    private location: Location ) { 
  }

  async getMieter() {
    const id = +this.route.snapshot.paramMap.get('id')
    try {
      this.mieter = await this.mieterService.getMieter(id)
      this.zahlungenForderungen = await this.zahlungForderungService.getZahlungenForderungenByMieterAndYear(id, +this.year)
    } catch (err) {
      this.messageService.add(JSON.stringify(err, undefined, 4))
    }
  }

  async getZahlungenForderungen() {
    const id = this.mieter?.id ?? 0
    try {
      this.zahlungenForderungen = await this.zahlungForderungService.getZahlungenForderungenByMieterAndYear(id, +this.year)
    } catch (err) {
      this.messageService.add(JSON.stringify(err, undefined, 4))
    }
  }

  onYearInput(): void {
    this.getZahlungenForderungen()
  }

  async ngOnInit(): Promise<void> {
    this.year = new Date().getFullYear().toString()
    await this.getMieter()
    await this.getZahlungenForderungen()
  }
}
